' TYPE              Automation
' DESCRIPTION       Remote control for using IRTrans
'                   
' AUTHOR            I A Heaton, Prism Sound Ltd
' HISTORY           initial version based on Slink-E 3/9/04
'                   Modified for IRTrans 6/04                
'==========================================================


'==========================================================
' Declarations
'==========================================================
Option Explicit         ' Must declare all variables before using them
Dim i                   ' counter for loops
Dim IRRemote            ' The form object
Dim iWidth2             ' Width of 2 buttons
Dim iWidth4             ' Width of 4 buttons
Dim iWidth8             ' Width of 8 buttons
Dim strDesc             ' String used for descriptions
Dim iMessageTextRed     ' Red part of message text colour
Dim iMessageTextGreen   ' Green part of message text colour
Dim iMessageTextBlue    ' Blue part of message text colour
Dim iMessageBkgndRed    ' Red part of background colour
Dim iMessageBkgndGreen  ' Green part of background colour
Dim iMessageBkgndBlue   ' Blue part of background colour
Dim strFont             ' Font name
Dim iFontSize           ' Point size of font
Dim strhlp              ' Helptext for selected button
Dim strnyi              ' String to display the text "Not Yet Implemented"
Dim ibuttonwidth        ' To scale the size of the buttons
Dim igrey               ' to define the button colour
Dim itext               ' to define text shade
Dim Wshshell            ' Windows Scripting Host Shell object
Dim strbox              ' string title for message boxes etc.
Dim starttime           ' start time of a particular activity for controlling time-outs.

'IR controller variables
Dim IRTrans             ' IRTrans object
Dim devname             ' IRTrans Device name
Dim Result              ' Return from IRTrans command
Dim bConnected          ' true when connection is established

Dim iTXDelay            ' Delay between re-transmissions
Dim iTXRetries          ' Number of times to retry the IR transmission
                        ' Note this should not be used for numbers, navigation or toggles

'Command Names for converting to different systems
Dim Play, Pause, SkipFwd, SkipBack, Stopbutton
Dim One, two, three, four, five, six, seven, eight, nine, zero, plusten
Dim bplusten            ' true if the disk navigation uses a +10 button
Dim Power, eject, setup, diskmenu, systemmenu, title, esckey, menu
Dim besckey             ' true if the escape key is being used.
Dim Cursorup, CursorDown, CursorRight, CursorLeft, OK, Return

'User Key control
Dim bUser1, bUser2, bUser3, bUser4  ' true if we are using these keys
Dim strUser1, struser2, struser3, struser4  'the names that appear (keep short!!!)
Dim User1, User2, User3, User4      ' The IR commands sent by these buttons


'Key Repeat Initialisation
iTXDelay = 50
iTXRetries = 0 ' 0 = no retries, ie only try once

'==========================================================
'SET-UP SECTION - MAKE CHANGES HERE:
'==========================================================

    'The name of the device to control as defined in the IRTrans library
    'devname = "Pioneer DV340" 
    'devname = "Panasonic DVD-RA82"
    devname = "Toshiba SD-120E"
    
    
    'the name that appear on message boxes
    strbox =  devname & " remote control"

    'Set the commands below to the correct names as used in the 
    'the selected IR library:
    'This is NOT the place to change the name that appears on the buttons!
        
    'Transport:
    Play        = "play"
    Stopbutton  = "stop"
    Pause       = "Pause"
    SkipFwd     = "skip+"
    SkipBack    = "skip-"
    
    'Keypad
    one         = "1"
    two         = "2"
    three       = "3"
    four        = "4"
    five        = "5"
    six         = "6"
    seven       = "7"
    eight       = "8"
    nine        = "9"
    zero        = "0"
    plusten     = "plusten"
    
    'Navigation/Cursor
    Cursorup    = "cursor_up"
    CursorDown  = "cursor_down"
    CursorRight = "cursor_right"
    CursorLeft  = "cursor_left"
    OK          = "OK"
    Return      = "return"
    esckey      = "esckey"
    besckey     = true
    
    'System
    Power       = "standby"
    'Power       = "Power"
    eject       = "eject"
    
    'setup and menu buttons
    setup       = "setup"
    menu        = "menu"
    
    'Use this line to specify if the system uses a +10 key (true = yes)
    bPlusten    = true
    
    'User Keys x 4
    'Use this section to customise the four user keys
    buser1      = true          ' True means key is in use
    struser1    = "TMENU"          ' name on button (keep it very short!)
    user1       = "topmenu"       ' IR command to link to
    
    buser2      = true
    struser2    = ">>"
    user2       = "FWD"
    
    buser3      = true
    struser3    = "T"
    user3       = "T"
    
    buser4      = true
    struser4    = "AUD"
    user4       = "Audio"

    
'==========================================================
'END OF SET-UP SECTION 
'==========================================================

' Include access to Coloured message box
'#Include "Useful\ColourMsgBox.dss"

'==========================================================
'Main bit
'==========================================================

    ' Variables - Colours, fonts etc
    iMessageTextRed     = 255    ' Message box text is white
    iMessageTextGreen   = 255
    iMessageTextBlue    = 255
    iMessageBkgndRed    = 58     ' Message box background is blue
    iMessageBkgndGreen  = 110
    iMessageBkgndBlue   = 165
    igrey               = 160
    itext               = 50
    strFont             = "Arial"
    iFontSize           = 6
    strnyi = "Not yet implemented"
    strhlp = strnyi
    ibuttonwidth        = 15
    iwidth2 = (2 * ibuttonwidth) + 5
    iwidth4 = (4 * ibuttonwidth) + 15
    iwidth8 = (8 * ibuttonwidth) + 35
    
    bConnected = false

    'Set up IRTrans
    Set IRTrans = wscript.CreateObject("IRTransOCX.IRTrans", "IRTrans_")

    If IsEmpty(IRTrans) Then
        MsgBox "Failed to create IRTransOCX Control"
    End If
    IRTrans.ServerIP = "localhost"
    
    IRTrans.Connect()
    
    starttime = timer()
    Do while bConnected = false and timer()-starttime < 10
        wscript.Sleep(100)
    Loop    
    
    
    ' Create the form object
    Set IRRemote = CreateObject("ScriptDlg.Form")
    With IRRemote
        .Title = "IR control"
        .XPos = 50
        .YPos = 100
        .SetFont strFont, iFontSize
        .InitEventHandler(IRRemote)

        ' Description
        .AddStatic "Remote1", left(devname,20), (iwidth4)
        With .Remote1
            .SetTextColour iMessageTextRed, iMessageTextGreen, iMessageTextBlue
            .SetBackgroundColour iMessageBkgndRed, iMessageBkgndGreen, iMessageBkgndBlue
            .SetFont strfont, 9, 1
            .Alignment = 18
        End With
        .NewRow()
    
        'Power and Eject Buttons
        .AddPushbutton "Power","POWER", iwidth2 
        .Power.setbackgroundcolour igrey, igrey, igrey
        .Power.settextcolour itext, itext, itext
        .Power.SetEvent_OnClick GetRef("Power_OnClick")
        .AddPushbutton "Eject","EJECT", iwidth2
        .Eject.setbackgroundcolour igrey, igrey, igrey
        .Eject.settextcolour itext, itext, itext
        .Eject.SetEvent_OnClick GetRef("Eject_OnClick")
        .NewRow()
    
        'Setup and Menu controls
        .AddPushbutton "Setup","SETUP", iwidth2
        .Setup.setbackgroundcolour igrey, igrey, igrey
        .Setup.settextcolour itext, itext, itext
        .Setup.SetEvent_OnClick GetRef("Setup_OnClick")
        .AddPushbutton "Menu","MENU", iwidth2
        .Menu.setbackgroundcolour igrey, igrey, igrey
        .Menu.settextcolour itext, itext, itext
        .Menu.SetEvent_OnClick GetRef("Menu_OnClick")
        .NewRow()

        'Divider line
        .AddStatic "Remote2","", (iwidth4), 2, 2 
        .Remote2.SetTextColour iMessageTextRed, iMessageTextGreen, iMessageTextBlue
        .Remote2.SetBackgroundColour iMessageBkgndRed, iMessageBkgndGreen, iMessageBkgndBlue
        .NewRow()

    End With
        
        
    If (buser1 or buser2) then
        'User1 and User2 controls
        With IRRemote
            .AddPushbutton "User1", struser1, iwidth2
            .User1.setbackgroundcolour igrey, igrey, igrey
            .User1.settextcolour itext, itext, itext
            .User1.SetEvent_OnClick GetRef("User1_OnClick")
            .User1.visible = buser1
            .AddPushbutton "User2", struser2, iwidth2
            .User2.setbackgroundcolour igrey, igrey, igrey
            .User2.settextcolour itext, itext, itext
            .User2.SetEvent_Onclick GetRef("User2_Onclick")
            .User2.visible = buser2 
            .NewRow()
        End With
    End If        
    
    'User3 and User4 controls
    If (buser3 or buser4) then
        With IRRemote
            .AddPushbutton "User3", struser3 , iwidth2
            .User3.setbackgroundcolour igrey, igrey, igrey
            .User3.settextcolour itext, itext, itext
            .User3.SetEvent_OnClick GetRef("User3_OnClick")
            .User3.visible = buser3
            .AddPushbutton "User4", struser4, iwidth2
            .User4.setbackgroundcolour igrey, igrey, igrey
            .User4.settextcolour itext, itext, itext
            .User4.SetEvent_Onclick GetRef("User4_Onclick")
            .User4.visible = buser4
            .NewRow()
        End With    
    End If    
    
    'Divider line if we use any user buttons
    If buser1 or buser2 or buser3 or buser4 then
        IRRemote.AddStatic "Remote3","", (iwidth4), 2
        IRRemote.Remote3.SetTextColour iMessageTextRed, iMessageTextGreen, iMessageTextBlue
        IRRemote.Remote3.SetBackgroundColour iMessageBkgndRed, iMessageBkgndGreen, iMessageBkgndBlue
        IRRemote.NewRow()
    End If

    With IRRemote
        .AddPushbutton "esckey1","ESC", iwidth2
        .esckey1.setbackgroundcolour igrey, igrey, igrey
        .esckey1.settextcolour 0, itext, 0
        .esckey1.SetEvent_OnClick GetRef("esckey_OnClick")
        .esckey1.visible = besckey 
        .AddPushbutton "Return","RTN", iwidth2
        .Return.setbackgroundcolour igrey, igrey, igrey
        .Return.settextcolour 0, itext, 0
        .Return.SetEvent_OnClick GetRef("Return_OnClick")
        .NewRow()
        .NewRow()
    
        'Cursor
        .AddPushbutton "CursorUp", "^", 22, -1, 30
        .cursorup.setbackgroundcolour igrey, igrey, igrey
        .cursorup.settextcolour 0, itext, 0
        .CursorUp.SetEvent_OnClick GetRef("CursorUp_OnClick")
        .NewRow()
        .AddPushbutton "CursorLeft", "<", 22
        .cursorleft.setbackgroundcolour igrey, igrey, igrey
        .cursorleft.settextcolour 0, itext, 0
        .cursorLeft.SetEvent_OnClick GetRef("CursorLeft_OnClick")
        .AddPushbutton "Enter", "OK", 22
        .Enter.setbackgroundcolour igrey, igrey, igrey
        .Enter.settextcolour 0, itext, 0
        .Enter.SetEvent_OnClick GetRef("Enter_OnClick")
        .Addpushbutton "CursorRight", ">", 22
        .cursorright.setbackgroundcolour igrey, igrey, igrey
        .cursorright.settextcolour 0, itext, 0
        .CursorRight.SetEvent_OnClick GetRef ("CursorRight_OnClick")
        .NewRow()
        .Addpushbutton "CursorDown", "v", 22, -1, 30
        .CursorDown.SetEvent_OnClick GetRef ("CursorDown_OnClick")
        .cursordown.setbackgroundcolour igrey, igrey, igrey
        .cursordown.settextcolour 0, itext, 0
        .NewRow()
        .NewRow()
    
        ' Transport Buttons
        .AddPushbutton "Skipback", "I<", iButtonWidth
        .Skipback.setbackgroundcolour igrey, igrey, igrey
        .Skipback.settextcolour 0, itext, 0
        .Skipback.SetEvent_OnClick GetRef("Skipback_OnClick")
        .AddPushbutton "Play", "PLAY", iWidth2
        .Play.setbackgroundcolour igrey, igrey, igrey
        .Play.settextcolour 0, 150, 0
        .Play.SetEvent_OnClick GetRef("Play_OnClick")
        .AddPushbutton "Skipfwd", ">I", iButtonWidth
        .skipfwd.setbackgroundcolour igrey, igrey, igrey
        .skipfwd.settextcolour 0, itext, 0
        .skipfwd.SetEvent_OnClick GetRef("skipfwd_OnClick")
        .NewRow()
        .Addpushbutton "Stop", "STOP", iwidth2
        .stop.setbackgroundcolour igrey, igrey, igrey
        .stop.settextcolour 200, 0, 0
        .stop.SetEvent_OnClick GetRef ("Stop_OnClick")
        .Addpushbutton "Pause", "PAUSE", iwidth2
        .Pause.setbackgroundcolour igrey, igrey, igrey
        .Pause.settextcolour itext, itext, 0
        .Pause.SetEvent_OnClick GetRef ("Pause_OnClick")
        .NewRow()
        .NewRow()
    

        'Number Buttons
        .AddPushButton "Num1", "1", 22
        .Num1.setbackgroundcolour igrey, igrey, igrey
        .Num1.settextcolour itext, itext, itext
        .Num1.SetFont strfont, 7, 1
        .Num1.SetEvent_OnClick GetRef("Num1_OnClick")
        .AddPushButton "Num2", "2", 22
        .Num2.setbackgroundcolour igrey, igrey, igrey
        .Num2.settextcolour itext, itext, itext
        .Num2.SetFont strfont, 7, 1
        .Num2.SetEvent_OnClick GetRef("Num2_OnClick")
        .AddPushButton "Num3", "3", 22
        .Num3.setbackgroundcolour igrey, igrey, igrey
        .Num3.SetFont strfont, 7, 1
        .Num3.settextcolour itext, itext, itext
        .Num3.SetEvent_OnClick GetRef("Num3_OnClick")
        .NewRow()
        .AddPushButton "Num4", "4", 22
        .Num4.setbackgroundcolour igrey, igrey, igrey
        .Num4.SetFont strfont, 7, 1
        .Num4.settextcolour itext, itext, itext
        .Num4.SetEvent_OnClick GetRef("Num4_OnClick")        
        .AddPushButton "Num5", "5", 22
        .Num5.setbackgroundcolour igrey, igrey, igrey
        .Num5.SetFont strfont, 7, 1
        .Num5.settextcolour itext, itext, itext
        .Num5.SetEvent_OnClick GetRef("Num5_OnClick")
        .AddPushButton "Num6", "6", 22
        .Num6.setbackgroundcolour igrey, igrey, igrey
        .Num6.SetFont strfont, 7, 1
        .Num6.settextcolour itext, itext, itext
        .Num6.SetEvent_OnClick GetRef("Num6_OnClick")
        .NewRow()
        .AddPushButton "Num7", "7", 22
        .Num7.setbackgroundcolour igrey, igrey, igrey
        .Num7.SetFont strfont, 7, 1
        .Num7.settextcolour itext, itext, itext
        .Num7.SetEvent_OnClick GetRef("Num7_OnClick")
        .AddPushButton "Num8", "8", 22
        .Num8.setbackgroundcolour igrey, igrey, igrey
        .Num8.SetFont strfont, 7, 1
        .Num8.settextcolour itext, itext, itext
        .Num8.SetEvent_OnClick GetRef("Num8_OnClick")
        .AddPushButton "Num9", "9", 22
        .Num9.setbackgroundcolour igrey, igrey, igrey
        .Num9.SetFont strfont, 7, 1
        .Num9.settextcolour itext, itext, itext
        .Num9.SetEvent_OnClick GetRef("Num9_OnClick")
        .NewRow()
        .AddPushButton "Num0", "0", 22, -1, 30
        .Num0.setbackgroundcolour igrey, igrey, igrey
        .Num0.SetFont strfont, 7, 1
        .Num0.settextcolour itext, itext, itext
        .Num0.SetEvent_OnClick GetRef("Num0_OnClick")
        .AddPushButton "plusten1", "+10", 22
        With .Plusten1
            .setbackgroundcolour igrey, igrey, igrey
            .SetFont strfont, 7, 1
            .settextcolour itext, itext, itext
            .SetEvent_OnClick GetRef("plusten_OnClick")
            .visible = bplusten    'show plusten button only if enabled
        End With
        .NewRow()

        .SetEvent_OnClose GetRef ("Leave_OnClick")

        ' Actually show the form...
        .Display()
    End With 'IRRemote
    
    wscript.sleep(5000)
        


' *** Event handlers ***

'==========================================================
Sub Skipback_OnClick()
'==========================================================
    For i = 0 to iTXRetries
        IRTrans.SendIR Cstr(devname), Cstr(SkipBack)
        wscript.sleep(iTXdelay)
    Next
End Sub 


'==========================================================
Sub Play_OnClick()
'==========================================================
    For i = 0 to iTXRetries
        IRTrans.SendIR Cstr(devname), Cstr(play)
        wscript.sleep(iTXdelay)
    Next
End Sub


'==========================================================
Sub skipfwd_OnClick()
'==========================================================
    IRTrans.SendIR Cstr(devname), Cstr(SkipFwd)
End Sub


'==========================================================
Sub Stop_OnClick()  
'==========================================================
    For i = 0 to iTXRetries
        IRTrans.SendIR Cstr(devname), Cstr(Stopbutton)
        wscript.sleep(iTXdelay)
    Next
End Sub


'==========================================================
Sub Pause_OnClick()
'==========================================================
    For i = 0 to iTXRetries
        IRTrans.SendIR Cstr(devname), Cstr(pause)
        wscript.sleep(iTXdelay)
    Next
End Sub


'==========================================================
Sub CursorUp_OnClick()
'==========================================================
    IRTrans.SendIR Cstr(devname), Cstr(Cursorup)
End Sub


'==========================================================
Sub CursorLeft_OnClick()
'==========================================================
    IRTrans.SendIR Cstr(devname), Cstr(CursorLeft)
End Sub


'==========================================================
Sub Enter_OnClick()
'==========================================================
    IRTrans.SendIR Cstr(devname), Cstr(OK)
End Sub


'==========================================================
Sub CursorRight_OnClick()
'==========================================================
    IRTrans.SendIR Cstr(devname), Cstr(cursorright)
End Sub


'==========================================================
Sub CursorDown_OnClick()
'==========================================================
    IRTrans.SendIR Cstr(devname), Cstr(cursordown)
End Sub


'==========================================================
Sub Num1_OnClick()
'==========================================================
    IRTrans.SendIR Cstr(devname), Cstr(one)
End Sub


'==========================================================
Sub Num2_OnClick()
'==========================================================
    IRTrans.SendIR Cstr(devname), Cstr(two)
End Sub


'==========================================================
Sub Num3_OnClick()
'==========================================================
    IRTrans.SendIR Cstr(devname), Cstr(three)
End Sub


'==========================================================
Sub Num4_OnClick()
'==========================================================
    IRTrans.SendIR Cstr(devname), Cstr(four)
End Sub


'==========================================================
Sub Num5_OnClick()
'==========================================================
    IRTrans.SendIR Cstr(devname), Cstr(five)
End Sub


'==========================================================
Sub Num6_OnClick()
'==========================================================
    IRTrans.SendIR Cstr(devname), Cstr(six)
End Sub


'==========================================================
Sub Num7_OnClick()
'==========================================================
    IRTrans.SendIR Cstr(devname), Cstr(seven)
End Sub


'==========================================================
Sub Num8_OnClick()
'==========================================================
    IRTrans.SendIR Cstr(devname), Cstr(eight)
End Sub


'==========================================================
Sub Num9_OnClick()
'==========================================================
    IRTrans.SendIR Cstr(devname), Cstr(nine)
End Sub


'==========================================================
Sub Num0_OnClick()
'==========================================================
    IRTrans.SendIR Cstr(devname), Cstr(zero)
End Sub


'==========================================================
Sub plusten_OnClick()
'==========================================================
    IRTrans.SendIR Cstr(devname), Cstr(plusten)
End Sub


'==========================================================
Sub Eject_OnClick()
'==========================================================
    IRTrans.SendIR Cstr(devname), Cstr(eject)
End Sub


'==========================================================
Sub Power_OnClick()
'==========================================================
    IRTrans.SendIR Cstr(devname), Cstr(Power)
End Sub


'==========================================================
Sub user1_OnClick()
'==========================================================
    IRTrans.SendIR Cstr(devname), Cstr(user1)
End Sub


'==========================================================
Sub user2_OnClick()
'==========================================================
    IRTrans.SendIR Cstr(devname), Cstr(user2)
End Sub


'==========================================================
Sub User3_OnClick()
'==========================================================
    IRTrans.SendIR Cstr(devname), Cstr(user3)
End Sub


'==========================================================
Sub User4_OnClick()
'==========================================================
    IRTrans.SendIR Cstr(devname), Cstr(user4)
End Sub

'==========================================================
Sub Return_OnClick()
'==========================================================
    IRTrans.SendIR Cstr(devname), Cstr(Return)
End Sub


'==========================================================
Sub esckey_OnClick()
'==========================================================
    IRTrans.SendIR Cstr(devname), Cstr(esckey)
End Sub


'==========================================================
Sub Setup_OnClick()
'==========================================================
    IRTrans.SendIR Cstr(devname), Cstr(Setup)
End Sub


'==========================================================
Sub menu_OnClick()
'==========================================================
    IRTrans.SendIR Cstr(devname), Cstr(menu)
End Sub


'==========================================================
Sub Leave_OnClick(sValue) 'Manages Exit button
'==========================================================
    set wshshell = nothing
    set IRTrans = nothing
    'End script

End Sub


'==========================================================
Sub IRFail
'==========================================================
    strhlp = "IR Automation Failure" & vbcrlf & vbcrlf & "The IR automation did not correctly execute a "
    strhlp = strhlp & "command.  This could be because: " & vbcrlf & " - the IR library does not contain a "
    strhlp = strhlp & "code corresponding to one called by the script." & vbcrlf & " - the IRTrans " 
    strhlp = strhlp & "has not initialised properly" & vbcrlf & " - there is a connection problem between "
    strhlp = strhlp & "the computer and the IRTrans." & vbcrlf
    strhlp = strhlp & " - The IRTrans Server is not running or the address is wrong "
    msgbox strhlp, vbexclamation, "IR Remote"

End Sub

'==========================================================
' IRTrans Event Handling is not possible in DSS?!
'==========================================================

'==========================================================
Sub IRTrans_Connected()
'==========================================================
    bConnected = true
    'MsgBox "IRTrans Connected successfully"
End Sub


'==========================================================
Function IRTrans_ConnectError(msg, ierror)
'==========================================================
    MsgBox "IRTrans connection error:  "&  msg & "   " & ierror,  vbexclamation, strbox
    bConnected = false
    Call StartIRTRansServer
End Function


'==========================================================
Sub StartIRTRansServer
'==========================================================

    'Open WSH
    Set WshShell = CreateObject("WScript.Shell")
    
    'Load the IRTrans server - this proved to not work by the normal methods.
    return = WshShell.Run ("cmd.exe")
    wscript.sleep(300)
    WshShell.AppActivate "C:\windows\system 32\cmd.exe"
    WshShell.SendKeys "cd"
    WshShell.SendKeys " "
    WshShell.SendKeys "+2C:\Program"
    WshShell.SendKeys " "
    WshShell.SendKeys "Files\IRTrans"
    WshShell.SendKeys "~"
    wscript.sleep(300)
    WshShell.SendKeys "irtranstray.exe"
    WshShell.SendKeys " " 
    WshShell.SendKeys "usb"
    WshShell.SendKeys "~"
    WshShell.Sendkeys "exit"
    WshShell.Sendkeys "~"
    wscript.sleep (2000)
    IRtrans.connect()
    
End Sub


'==========================================================
Sub IRTRans_CommandReady()
'==========================================================
    'MsgBox "IRTrans command sent OK", vbinformation, strbox
End Sub


'==========================================================
Function IRTrans_Error(msg, strError, istatuslevel)
'==========================================================
    MsgBox msg & " : " & strError &  "  (" & iSTatuslevel & ")", vbexclamation, strbox
End Function


'==========================================================
Sub IRTRans_Receive(remoteID, command, strdata )
'==========================================================
    'MsgBox "IRTrans command received " & vbcrlf & remoteID & ":   " & command & vbcrlf & strdata, vbinformation, strbox
End Sub
